summaryrefslogtreecommitdiffstats
path: root/installer
diff options
context:
space:
mode:
authorramon <ramongomez@us.es>2014-05-05 11:41:50 +0000
committerramon <ramongomez@us.es>2014-05-05 11:41:50 +0000
commit0f8100d2a9ebdfcab940127fa399bfac76ae0409 (patch)
tree212a69e8407d40ac3c71cdb407b2e0327244afcd /installer
parentd2154f49cea5c73089b480abfc5cb9646ed21c28 (diff)
#616: Instalador compatible con distribuciones GNU/Linux que sustituyen MySQL por MariaDB (como Fedora 20).
git-svn-id: https://opengnsys.es/svn/branches/version1.0@4265 a21b9725-9963-47de-94b9-378ad31fedc9
Diffstat (limited to 'installer')
-rwxr-xr-xinstaller/opengnsys_installer.sh9
1 files changed, 6 insertions, 3 deletions
diff --git a/installer/opengnsys_installer.sh b/installer/opengnsys_installer.sh
index 5575be98..5a2ac40c 100755
--- a/installer/opengnsys_installer.sh
+++ b/installer/opengnsys_installer.sh
@@ -127,7 +127,8 @@ OPENGNSYS_DB_CREATION_FILE=opengnsys/admin/Database/${OPENGNSYS_DATABASE}.sql
# - INETDSERV - servicio Inetd
# - IPTABLESSERV - servicio IPTables
# - DHCPSERV, DHCPCFGDIR - servicio y configuración de DHCP
# - MYSQLSERV, TMPMYCNF - servicio MySQL y fichero temporal con credenciales de acceso.
# - RSYNCSERV, RSYNCCFGDIR - servicio y configuración de Rsync
# - SAMBASERV, SAMBACFGDIR - servicio y configuración de Samba
# - TFTPSERV, TFTPCFGDIR, SYSLINUXDIR - servicio y configuración de TFTP/PXE
@@ -172,6 +173,7 @@ case "$OSDISTRIB" in
INETDSERV=xinetd
INETDCFGDIR=/etc/xinetd.d
MYSQLSERV=mysql
+ MARIADBSERV=mariadb
RSYNCSERV=rsync
RSYNCCFGDIR=/etc
SAMBASERV=smbd
@@ -211,6 +213,7 @@ case "$OSDISTRIB" in
INETDCFGDIR=/etc/xinetd.d
IPTABLESSERV=iptables
MYSQLSERV=mysqld
+ MARIADBSERV=mariadb
RSYNCSERV=rsync
RSYNCCFGDIR=/etc
SAMBASERV=smb
@@ -1662,8 +1665,8 @@ fi
# Instalar Base de datos de OpenGnSys Admin.
isInArray notinstalled "mysql-server"
if [ $? -eq 0 ]; then
- service=$MYSQLSERV
- $ENABLESERVICE; $STARTSERVICE
+ service=$MYSQLSERV $ENABLESERVICE || service=$MARIADBSERV $ENABLESERVICE
+ $STARTSERVICE
mysqlSetRootPassword "${MYSQL_ROOT_PASSWORD}"
else
mysqlGetRootPassword
@@ -127,7 +127,8 @@ OPENGNSYS_DB_CREATION_FILE=opengnsys/admin/Database/${OPENGNSYS_DATABASE}.sql
# - IPTABLESSERV - servicio IPTables
# - DHCPSERV, DHCPCFGDIR - servicio y configuración de DHCP
-# - MYSQLSERV, TMPMYCNF - servicio MySQL y fichero temporal con credenciales de acceso.
+# - MYSQLSERV, TMPMYCNF - servicio MySQL y fichero temporal con credenciales de acceso
+# - MARIADBSERV - servicio MariaDB (sustituto de MySQL en algunas distribuciones)
# - RSYNCSERV, RSYNCCFGDIR - servicio y configuración de Rsync
# - SAMBASERV, SAMBACFGDIR - servicio y configuración de Samba